ConfidenceInterval

Struct ConfidenceInterval 

pub struct ConfidenceInterval<T> { /* private fields */ }
A statistical confidence interval.

A confidence interval represents a bounded range of values associated with a statistical estimate, together with a confidence level describing the reliability of the construction procedure.

Structure

A confidence interval consists of:

Geometry

The interval is closed:

lower ≤ x ≤ upper

Implementations

Source

impl<T: Copy> ConfidenceInterval<T>

pub fn level(&self) -> ConfidenceLevel<T>

Returns the confidence level associated with the confidence interval

Source

impl<T: Float> ConfidenceInterval<T>

pub fn new( lower: T, upper: T, confidence_level: ConfidenceLevel<T>, ) -> Result<Self, ValidationError>

Creates a confidence interval from a lower and upper bounds and a confidence level.

Examples
use confi::{ConfidenceInterval, ConfidenceLevel};

let cl = ConfidenceLevel::new(0.95)?;
let (lower, upper) = (0.0, 1.0);

let ci = ConfidenceInterval::new(lower, upper, cl)?;

assert_eq!(ci.lower(), lower);
assert_eq!(ci.upper(), upper);
assert_eq!(ci.level().into_inner(), 0.95);
Errors
  • If the lower or upper bound are NaN
  • If the lower or upper bound are infinite
  • If the lower or upper bound do not form an ordered interval
Source

impl<T: Float> ConfidenceInterval<T>

pub fn lower(&self) -> T

Returns the lower bound for the confidence interval

Examples
use confi::{ConfidenceInterval, ConfidenceLevel};

let cl = ConfidenceLevel::new(0.95)?;
let (lower, upper) = (0.0, 1.0);

let ci = ConfidenceInterval::new(lower, upper, cl)?;

assert_eq!(ci.lower(), lower);
pub fn upper(&self) -> T

Returns the upper bound for the confidence interval

Examples
use confi::{ConfidenceInterval, ConfidenceLevel};

let cl = ConfidenceLevel::new(0.95)?;
let (lower, upper) = (0.0, 1.0);

let ci = ConfidenceInterval::new(lower, upper, cl)?;

assert_eq!(ci.upper(), upper);
Source

impl<T: Float> ConfidenceInterval<T>

pub fn contains(&self, value: T) -> bool

Returns true if the interval contains the argument

Examples
use confi::{ConfidenceInterval, ConfidenceLevel};

let cl = ConfidenceLevel::new(0.95)?;
let (lower, upper) = (0.0, 1.0);

let ci = ConfidenceInterval::new(lower, upper, cl)?;

assert_eq!(ci.contains(0.5), true);
assert_eq!(ci.contains(1.5), false);
pub fn width(&self) -> T

Returns the width of the confidence interval

Examples
use confi::{ConfidenceInterval, ConfidenceLevel};

let cl = ConfidenceLevel::new(0.95)?;
let (lower, upper) = (0.0, 1.0);

let ci = ConfidenceInterval::new(lower, upper, cl)?;

assert_eq!(ci.width(), upper - lower);
pub fn centre(&self) -> T

Returns the centre of the confidence interval

Examples
use confi::{ConfidenceInterval, ConfidenceLevel};

let cl = ConfidenceLevel::new(0.95)?;
let (lower, upper) = (0.0, 1.0);

let ci = ConfidenceInterval::new(lower, upper, cl)?;

assert_eq!(ci.centre(), 0.5);
pub fn radius(&self) -> T

Returns the radius of the confidence interval

Examples
use confi::{ConfidenceInterval, ConfidenceLevel};

let cl = ConfidenceLevel::new(0.95)?;
let (lower, upper) = (0.0, 1.0);

let ci = ConfidenceInterval::new(lower, upper, cl)?;

assert_eq!(ci.radius(), 0.5);
Source

impl<T> ConfidenceInterval<T>
where T: ToPrimitive,