ConfidenceLevel

Struct ConfidenceLevel 

pub struct ConfidenceLevel<T>(/* private fields */);
A statistical confidence level.

Represents a probability in the closed interval [0, 1].

Common values include:

  • 0.90 (90%)
  • 0.95 (95%)
  • 0.99 (99%)

A confidence level c corresponds to a significance level α = 1 - c.

Implementations

Source

impl ConfidenceLevel<f32>

pub const CL90: Self

pub const CL95: Self

pub const CL975: Self

pub const CL99: Self

pub const CL999: Self

Source

impl ConfidenceLevel<f64>

pub const CL90: Self

pub const CL95: Self

pub const CL975: Self

pub const CL99: Self

pub const CL999: Self

Source

impl<T> ConfidenceLevel<T>

pub fn into_inner(self) -> T

Returns the probability associated with the confidence level

Source

impl<T: Float> ConfidenceLevel<T>

pub fn new(probability: T) -> Result<Self, ValidationError>

Creates a confidence level from a probability.

Examples
use confi::ConfidenceLevel;

let cl = ConfidenceLevel::new(0.95)?;
assert_eq!(cl.into_inner(), 0.95);
Errors
  • If the provided probability is outside [0, 1]
  • If the provided probability is NaN
pub fn significance(self) -> SignificanceLevel<T>

Convert to the associated significance level

As confidence levels are checked for validity on creation the conversion is infallible

Examples
use confi::ConfidenceLevel;

let cl = ConfidenceLevel::new(0.95)?;
let significance = cl.significance();
approx::assert_relative_eq!(significance.into_inner(), 0.05);
Source

impl<T: Float + FromPrimitive> ConfidenceLevel<T>

pub fn from_percent(percentage: T) -> Result<Self, ValidationError>

Creates a confidence level from a percentage.

Examples
use confi::ConfidenceLevel;

let cl = ConfidenceLevel::from_percent(95.0)?;
assert_eq!(cl.into_inner(), 0.95);
Errors
  • If the provided percentage is outside [0, 100]
  • If the provided percentage is NaN
Source

impl<T: ToPrimitive> ConfidenceLevel<T>